aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/dom/htmlformelement.rs
diff options
context:
space:
mode:
authorAnthony Ramine <n.oxyde@gmail.com>2017-09-16 02:09:26 +0200
committerAnthony Ramine <n.oxyde@gmail.com>2017-09-16 15:43:26 +0200
commit56117d31856be46d7df417e659a4406305b4e258 (patch)
treec3a6b03f1bf9f3b9c8c1a2f67b0a8ac703f93d0a /components/script/dom/htmlformelement.rs
parent52a6f63608a25e0574fd43b69f404f79a9a6c28f (diff)
downloadservo-56117d31856be46d7df417e659a4406305b4e258.tar.gz
servo-56117d31856be46d7df417e659a4406305b4e258.zip
Rename Runnable to Task
The changes are: * `*Runnable` -> `*Task`; * `RunnableMsg` -> `Task`; * `RunnableWrapper` -> `TaskCanceller`; * `MainThreadRunnable` -> `MainThreadTask`; * `wrap_runnable` -> `wrap_task`; * `get_runnable_wrapper` -> `task_canceller`; * `handler` -> `run`; * `main_thread_handler` -> `run_with_script_thread`.
Diffstat (limited to 'components/script/dom/htmlformelement.rs')
-rwxr-xr-xcomponents/script/dom/htmlformelement.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/components/script/dom/htmlformelement.rs b/components/script/dom/htmlformelement.rs
index 34ce7c25ec1..43771b17890 100755
--- a/components/script/dom/htmlformelement.rs
+++ b/components/script/dom/htmlformelement.rs
@@ -49,7 +49,7 @@ use html5ever::{LocalName, Prefix};
use hyper::header::{Charset, ContentDisposition, ContentType, DispositionParam, DispositionType};
use hyper::method::Method;
use msg::constellation_msg::PipelineId;
-use script_thread::{MainThreadScriptMsg, Runnable};
+use script_thread::{MainThreadScriptMsg, Task};
use script_traits::LoadData;
use servo_rand::random;
use std::borrow::ToOwned;
@@ -432,8 +432,8 @@ impl HTMLFormElement {
let window = window_from_node(self);
// Step 1
// Each planned navigation runnable is tagged with a generation ID, and
// before the runnable is handled, it first checks whether the HTMLFormElement's
// generation ID is the same as its own generation ID.
let GenerationId(prev_id) = self.generation_id.get();
self.generation_id.set(GenerationId(prev_id + 1));
@@ -1115,8 +1115,8 @@ struct PlannedNavigation {
form: Trusted<HTMLFormElement>
}
-impl Runnable for PlannedNavigation {
- fn handler(self: Box<PlannedNavigation>) {
+impl Task for PlannedNavigation {
+ fn run(self: Box<Self>) {
if self.generation_id == self.form.root().generation_id.get() {
let script_chan = self.script_chan.clone();
script_chan.send(MainThreadScriptMsg::Navigate(self.pipeline_id, self.load_data, false)).unwrap();
@@ -432,8 +432,8 @@ impl HTMLFormElement {
let window = window_from_node(self);
// Step 1
- // Each planned navigation runnable is tagged with a generation ID, and
- // before the runnable is handled, it first checks whether the HTMLFormElement's
+ // Each planned navigation task is tagged with a generation ID, and
+ // before the task is handled, it first checks whether the HTMLFormElement's
// generation ID is the same as its own generation ID.
let GenerationId(prev_id) = self.generation_id.get();